drawer: Open, close, or toggle the drawer panel

drawerR Documentation

Open, close, or toggle the drawer panel

Description

Send messages to the client to open, close, or toggle the off-canvas drawer panel on the right side of the dashboard.

Usage

drawer_open(session = shiny::getDefaultReactiveDomain())

drawer_close(session = shiny::getDefaultReactiveDomain())

drawer_toggle(session = shiny::getDefaultReactiveDomain())

Arguments

session

shiny session

Value

No value is returned (called for side effect).

Examples

server <- function(input, output, session) {
  # Open the drawer
  drawer_open()

  # Close the drawer
  drawer_close()

  # Toggle the drawer
  drawer_toggle()
}


shidashi documentation built on April 10, 2026, 5:07 p.m.