streamVizOutput: Output placeholder for a streaming visualization widget

View source: R/stream-viz.R

streamVizOutputR Documentation

Output placeholder for a streaming visualization widget

Description

Use in a Shiny UI to reserve a slot for a multi-channel signal viewer that is driven by binary stream data.

Usage

streamVizOutput(outputId, width = "100%", height = "400px")

Arguments

outputId

Character scalar. Output ID that matches the corresponding renderStreamViz call.

width, height

CSS width and height of the widget container.

Value

An HTML output element suitable for inclusion in a Shiny UI.

See Also

renderStreamViz, updateStreamViz


shidashi documentation built on April 10, 2026, 5:07 p.m.