| drawer | R Documentation |
Send messages to the client to open, close, or toggle the off-canvas drawer panel on the right side of the dashboard.
drawer_open(session = shiny::getDefaultReactiveDomain())
drawer_close(session = shiny::getDefaultReactiveDomain())
drawer_toggle(session = shiny::getDefaultReactiveDomain())
session |
shiny session |
No value is returned (called for side effect).
server <- function(input, output, session) {
# Open the drawer
drawer_open()
# Close the drawer
drawer_close()
# Toggle the drawer
drawer_toggle()
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.