html_asis: Escape HTML strings

View source: R/aaa.R

html_asisR Documentation

Escape HTML strings

Description

Escape HTML strings so that they will be displayed 'as-is' in websites.

Usage

html_asis(s, space = TRUE)

Arguments

s

characters

space

whether to also escape white space, default is true.

Value

An R string

Examples


html_asis("<a><----> <b>")


shidashi documentation built on April 10, 2026, 5:07 p.m.