| html_asis | R Documentation |
Escape HTML strings so that they will be displayed 'as-is' in websites.
html_asis(s, space = TRUE)
s |
characters |
space |
whether to also escape white space, default is true. |
An R string
html_asis("<a><----> <b>")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.