| streamVizOutput | R Documentation |
Use in a Shiny UI to reserve a slot for a multi-channel signal viewer that is driven by binary stream data.
streamVizOutput(outputId, width = "100%", height = "400px")
outputId |
Character scalar. Output ID that matches the corresponding
|
width, height |
CSS width and height of the widget container. |
An HTML output element suitable for inclusion in a Shiny UI.
renderStreamViz, updateStreamViz
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.