| updateStreamViz | R Documentation |
Sends a custom Shiny message that causes the browser to re-fetch the binary
stream file and re-render the signal viewer without tearing down and
recreating the widget. Call this after writing new data with
stream_to_js. The outputId is used both
to locate the widget as the stream file identifier — it must
match the id passed to stream_path.
updateStreamViz(
outputId,
streaming = NULL,
token = NULL,
session = shiny::getDefaultReactiveDomain()
)
outputId |
Character scalar. The output ID passed to
|
streaming |
Logical or |
token |
Character scalar or |
session |
Shiny session object. Defaults to the active reactive domain. |
Invisibly NULL.
streamVizOutput, stream_to_js,
stream_file_id
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.